/* 
BASS 2.4.1, Aurora Include File, by KrYpT 2006\2007
See the BASS.CHM file for more complete documentation
http://www.un4seen.com/bass.html
*/
#ifndef BASS_H
#define BASS_H

#use "bass.lib"

#define BASSVERSION 0x204	// API version
#define BASSVERSIONTEXT "2.4"

#typedef HMUSIC   UNSIGNED INT 		// MOD music handle
#typedef HSAMPLE  UNSIGNED INT 		// sample handle
#typedef HCHANNEL UNSIGNED INT 		// playing sample's channel handle
#typedef HSTREAM  UNSIGNED INT 		// sample stream handle
#typedef HRECORD  UNSIGNED INT 		// recording handle
#typedef HSYNC    UNSIGNED INT 		// synchronizer handle
#typedef HDSP     UNSIGNED INT 		// DSP handle
#typedef HFX      UNSIGNED INT 		// DX8 effect handle
#typedef HPLUGIN  UNSIGNED INT 		// Plugin handle

//External Addons CTYPE 
#define BASS_TAG_MP4 		    7	    // iTunes/MP4 metadata
#define BASS_AAC_STEREO			0x400000// downmatrix to stereo
#define BASS_CTYPE_STREAM_AAC	0x10b00 // AAC
#define BASS_CTYPE_STREAM_MP4	0x10b01 // MP4
#define BASS_CONFIG_AC3_DYNRNG	0x10001 // AC3
#define BASS_AC3_DYNAMIC_RANGE	0x800	// enable dynamic range compression
#define BASS_CTYPE_STREAM_AC3	0x11000 // AC3
#define BASS_CTYPE_STREAM_ALAC	0x10e00 // Apple Lossless
#define BASS_CTYPE_STREAM_FLAC	0x10900 // Free Lossless FLAC
#define BASS_CTYPE_STREAM_FLAC_OGG	0x10901 // FLAC/OGG
#define BASS_CTYPE_STREAM_APE	0x10700 //Monkey audio
#define BASS_CTYPE_STREAM_MIDI	0x10d00 //Midi file

///////////////////////////////////////////////
// Error codes returned by BASS_ErrorGetCode //
///////////////////////////////////////////////
#define BASS_OK				0	// all is OK
#define BASS_ERROR_MEM		1	// memory error
#define BASS_ERROR_FILEOPEN	2	// can't open the file
#define BASS_ERROR_DRIVER	3	// can't find a free/valid driver
#define BASS_ERROR_BUFLOST	4	// the sample buffer was lost
#define BASS_ERROR_HANDLE	5	// invalid handle
#define BASS_ERROR_FORMAT	6	// unsupported sample format
#define BASS_ERROR_POSITION	7	// invalid playback position
#define BASS_ERROR_INIT		8	// BASS_Init has not been successfully called
#define BASS_ERROR_START	9	// BASS_Start has not been successfully called
#define BASS_ERROR_ALREADY	14	// already initialized/paused/whatever
#define BASS_ERROR_NOPAUSE	16	// not paused
#define BASS_ERROR_NOCHAN	18	// can't get a free channel
#define BASS_ERROR_ILLTYPE	19	// an illegal type was specified
#define BASS_ERROR_ILLPARAM	20	// an illegal parameter was specified
#define BASS_ERROR_NO3D		21	// no 3D support
#define BASS_ERROR_NOEAX	22	// no EAX support
#define BASS_ERROR_DEVICE	23	// illegal device number
#define BASS_ERROR_NOPLAY	24	// not playing
#define BASS_ERROR_FREQ		25	// illegal sample rate
#define BASS_ERROR_NOTFILE	27	// the stream is not a file stream
#define BASS_ERROR_NOHW		29	// no hardware voices available
#define BASS_ERROR_EMPTY	31	// the MOD music has no sequence data
#define BASS_ERROR_NONET	32	// no internet connection could be opened
#define BASS_ERROR_CREATE	33	// couldn't create the file
#define BASS_ERROR_NOFX		34	// effects are not available
#define BASS_ERROR_PLAYING	35	// the channel is playing
#define BASS_ERROR_NOTAVAIL	37	// requested data is not available
#define BASS_ERROR_DECODE	38	// the channel is a "decoding channel"
#define BASS_ERROR_DX		39	// a sufficient DirectX version is not installed
#define BASS_ERROR_TIMEOUT	40	// connection timedout
#define BASS_ERROR_FILEFORM	41	// unsupported file format
#define BASS_ERROR_SPEAKER	42	// unavailable speaker
#define BASS_ERROR_VERSION	43	// invalid BASS version (used by add-ons)
#define BASS_ERROR_CODEC	44  // codec is not available/supported
#define BASS_ERROR_UNKNOWN	-1	// some other mystery error

//////////////////////////
// Initialization flags //
//////////////////////////
#define BASS_DEVICE_8BITS	1	// use 8 bit resolution, else 16 bit
#define BASS_DEVICE_MONO	2	// use mono, else stereo
#define BASS_DEVICE_3D		4	// enable 3D functionality
/* If the BASS_DEVICE_3D flag is not specified when initilizing BASS,
then the 3D flags (BASS_SAMPLE_3D and BASS_MUSIC_3D) are ignored when
loading/creating a sample/stream/music. */
#define BASS_DEVICE_LATENCY	  256	// calculate device latency (BASS_INFO struct)
#define BASS_DEVICE_SPEAKERS  2048	// force enabling of speaker assignment
#define BASS_DEVICE_NOSPEAKER 4096	// ignore speaker arrangement

////////////////////////////////////////////////////////////////
// DirectSound interfaces (for use with BASS_GetDSoundObject) //
////////////////////////////////////////////////////////////////
#define BASS_OBJECT_DS		1	// IDirectSound
#define BASS_OBJECT_DS3DL	2	// IDirectSound3DListener

/////////////////////////////////////
// BASS_INFO flags (from DSOUND.H) //
/////////////////////////////////////
#define DSCAPS_CONTINUOUSRATE	0x00000010
/* supports all sample rates between min/maxrate */
#define DSCAPS_EMULDRIVER		0x00000020
/* device does NOT have hardware DirectSound support */
#define DSCAPS_CERTIFIED		0x00000040
/* device driver has been certified by Microsoft */
/* The following flags tell what type of samples are supported by HARDWARE
mixing, all these formats are supported by SOFTWARE mixing */
#define DSCAPS_SECONDARYMONO	0x00000100	// mono
#define DSCAPS_SECONDARYSTEREO	0x00000200	// stereo
#define DSCAPS_SECONDARY8BIT	0x00000400	// 8 bit
#define DSCAPS_SECONDARY16BIT	0x00000800	// 16 bit

///////////////////////////////////////////
// BASS_RECORDINFO flags (from DSOUND.H) //
///////////////////////////////////////////
#define DSCCAPS_EMULDRIVER	DSCAPS_EMULDRIVER	// device does NOT have hardware DirectSound recording support
#define DSCCAPS_CERTIFIED	DSCAPS_CERTIFIED	// device driver has been certified by Microsoft

// defines for formats field of BASS_RECORDINFO (from MMSYSTEM.H)
#ifndef WAVE_FORMAT_1M08
#define WAVE_FORMAT_1M08       0x00000001       /* 11.025 kHz, Mono,   8-bit  */
#define WAVE_FORMAT_1S08       0x00000002       /* 11.025 kHz, Stereo, 8-bit  */
#define WAVE_FORMAT_1M16       0x00000004       /* 11.025 kHz, Mono,   16-bit */
#define WAVE_FORMAT_1S16       0x00000008       /* 11.025 kHz, Stereo, 16-bit */
#define WAVE_FORMAT_2M08       0x00000010       /* 22.05  kHz, Mono,   8-bit  */
#define WAVE_FORMAT_2S08       0x00000020       /* 22.05  kHz, Stereo, 8-bit  */
#define WAVE_FORMAT_2M16       0x00000040       /* 22.05  kHz, Mono,   16-bit */
#define WAVE_FORMAT_2S16       0x00000080       /* 22.05  kHz, Stereo, 16-bit */
#define WAVE_FORMAT_4M08       0x00000100       /* 44.1   kHz, Mono,   8-bit  */
#define WAVE_FORMAT_4S08       0x00000200       /* 44.1   kHz, Stereo, 8-bit  */
#define WAVE_FORMAT_4M16       0x00000400       /* 44.1   kHz, Mono,   16-bit */
#define WAVE_FORMAT_4S16       0x00000800       /* 44.1   kHz, Stereo, 16-bit */
#endif

#define BASS_SAMPLE_8BITS		1	// 8 bit
#define BASS_SAMPLE_FLOAT		256	// 32-bit floating-point
#define BASS_SAMPLE_MONO		2	// mono
#define BASS_SAMPLE_LOOP		4	// looped
#define BASS_SAMPLE_3D			8	// 3D functionality enabled
#define BASS_SAMPLE_SOFTWARE	16	// it's NOT using hardware mixing
#define BASS_SAMPLE_MUTEMAX		32	// muted at max distance (3D only)
#define BASS_SAMPLE_VAM			64	// uses the DX7 voice allocation & management
#define BASS_SAMPLE_FX			128	// old implementation of DX8 effects are enabled
#define BASS_SAMPLE_OVER_VOL	0x10000	// override lowest volume
#define BASS_SAMPLE_OVER_POS	0x20000	// override longest playing
#define BASS_SAMPLE_OVER_DIST	0x30000 // override furthest from listener (3D only)

#define BASS_STREAM_PRESCAN		0x20000 // enable pin-point seeking (MP3/MP2/MP1)
#define BASS_MP3_SETPOS			BASS_STREAM_PRESCAN
#define BASS_STREAM_AUTOFREE	0x40000	// automatically free the stream when it stop/ends
#define BASS_STREAM_RESTRATE	0x80000	// restrict the download rate of internet file streams
#define BASS_STREAM_BLOCK		0x100000// download/play internet file stream in small blocks
#define BASS_STREAM_DECODE		0x200000// don't play the stream, only decode (BASS_ChannelGetData)
#define BASS_STREAM_STATUS		0x800000// give server status info (HTTP/ICY tags) in DOWNLOADPROC

#define BASS_MUSIC_FLOAT		BASS_SAMPLE_FLOAT // 32-bit floating-point
#define BASS_MUSIC_MONO			BASS_SAMPLE_MONO // force mono mixing (less CPU usage)
#define BASS_MUSIC_LOOP			BASS_SAMPLE_LOOP // loop music
#define BASS_MUSIC_3D			BASS_SAMPLE_3D // enable 3D functionality
#define BASS_MUSIC_FX			BASS_SAMPLE_FX // enable old implementation of DX8 effects
#define BASS_MUSIC_AUTOFREE		BASS_STREAM_AUTOFREE // automatically free the music when it stop/ends
#define BASS_MUSIC_DECODE		BASS_STREAM_DECODE // don't play the music, only decode (BASS_ChannelGetData)
#define BASS_MUSIC_PRESCAN		BASS_STREAM_PRESCAN	// calculate playback length
#define BASS_MUSIC_CALCLEN		BASS_MUSIC_PRESCAN
#define BASS_MUSIC_RAMP			0x200	// normal ramping
#define BASS_MUSIC_RAMPS		0x400	// sensitive ramping
#define BASS_MUSIC_SURROUND		0x800	// surround sound
#define BASS_MUSIC_SURROUND2	0x1000	// surround sound (mode 2)
#define BASS_MUSIC_FT2MOD		0x2000	// play .MOD as FastTracker 2 does
#define BASS_MUSIC_PT1MOD		0x4000	// play .MOD as ProTracker 1 does
#define BASS_MUSIC_NONINTER		0x10000	// non-interpolated mixing
#define BASS_MUSIC_POSRESET		0x8000	// stop all notes when moving position
#define BASS_MUSIC_POSRESETEX	0x400000// stop all notes and reset bmp/etc when moving position
#define BASS_MUSIC_STOPBACK		0x80000	// stop the music on a backwards jump effect
#define BASS_MUSIC_NOSAMPLE		0x100000// don't load the samples

//////////////////////////////
// Speaker assignment flags //
//////////////////////////////
#define BASS_SPEAKER_FRONT	0x1000000	// front speakers
#define BASS_SPEAKER_REAR	0x2000000	// rear/side speakers
#define BASS_SPEAKER_CENLFE	0x3000000	// center & LFE speakers (5.1)
#define BASS_SPEAKER_REAR2	0x4000000	// rear center speakers (7.1)
#define BASS_SPEAKER_LEFT	0x10000000	// modifier: left
#define BASS_SPEAKER_RIGHT	0x20000000	// modifier: right
#define BASS_SPEAKER_FRONTLEFT	BASS_SPEAKER_FRONT|BASS_SPEAKER_LEFT
#define BASS_SPEAKER_FRONTRIGHT	BASS_SPEAKER_FRONT|BASS_SPEAKER_RIGHT
#define BASS_SPEAKER_REARLEFT	BASS_SPEAKER_REAR|BASS_SPEAKER_LEFT
#define BASS_SPEAKER_REARRIGHT	BASS_SPEAKER_REAR|BASS_SPEAKER_RIGHT
#define BASS_SPEAKER_CENTER		BASS_SPEAKER_CENLFE|BASS_SPEAKER_LEFT
#define BASS_SPEAKER_LFE		BASS_SPEAKER_CENLFE|BASS_SPEAKER_RIGHT
#define BASS_SPEAKER_REAR2LEFT	BASS_SPEAKER_REAR2|BASS_SPEAKER_LEFT
#define BASS_SPEAKER_REAR2RIGHT	BASS_SPEAKER_REAR2|BASS_SPEAKER_RIGHT

#define BASS_UNICODE			0x80000000

#define BASS_RECORD_PAUSE		0x8000	// start recording paused

////////////////////////////////
// DX7 voice allocation flags //
////////////////////////////////
#define BASS_VAM_HARDWARE		1
/* Play the sample in hardware. If no hardware voices are available then
the "play" call will fail */
#define BASS_VAM_SOFTWARE		2
/* Play the sample in software (ie. non-accelerated). No other VAM flags
may be used together with this flag. */

////////////////////////////////
// DX7 voice management flags //
////////////////////////////////
/* These flags enable hardware resource stealing... if the hardware has no
available voices, a currently playing buffer will be stopped to make room for
the new buffer. NOTE: only samples loaded/created with the BASS_SAMPLE_VAM
flag are considered for termination by the DX7 voice management. */
#define BASS_VAM_TERM_TIME		4
/* If there are no free hardware voices, the buffer to be terminated will be
the one with the least time left to play. */
#define BASS_VAM_TERM_DIST		8
/* If there are no free hardware voices, the buffer to be terminated will be
one that was loaded/created with the BASS_SAMPLE_MUTEMAX flag and is beyond
it's max distance. If there are no buffers that match this criteria, then the
"play" call will fail. */
#define BASS_VAM_TERM_PRIO		16
/* If there are no free hardware voices, the buffer to be terminated will be
the one with the lowest priority. */

////////////////////////////
// BASS_CHANNELINFO types //
////////////////////////////
#define BASS_CTYPE_SAMPLE		1
#define BASS_CTYPE_RECORD		2
#define BASS_CTYPE_STREAM		0x10000
#define BASS_CTYPE_STREAM_OGG	0x10002
#define BASS_CTYPE_STREAM_MP1	0x10003
#define BASS_CTYPE_STREAM_MP2	0x10004
#define BASS_CTYPE_STREAM_MP3	0x10005
#define BASS_CTYPE_STREAM_AIFF	0x10006
#define BASS_CTYPE_STREAM_WAV	0x40000 // WAVE flag, LOWORD=codec
#define BASS_CTYPE_STREAM_WAV_PCM	0x50001
#define BASS_CTYPE_STREAM_WAV_FLOAT	0x50003
#define BASS_CTYPE_STREAM_WAV_MP3	0x50055
#define BASS_CTYPE_MUSIC_MOD	0x20000
#define BASS_CTYPE_MUSIC_MTM	0x20001
#define BASS_CTYPE_MUSIC_S3M	0x20002
#define BASS_CTYPE_MUSIC_XM		0x20003
#define BASS_CTYPE_MUSIC_IT		0x20004
#define BASS_CTYPE_MUSIC_MO3	0x00100 // MO3 flag

//////////////////////
// 3D channel modes //
//////////////////////
#define BASS_3DMODE_NORMAL		0
/* normal 3D processing */
#define BASS_3DMODE_RELATIVE	1
/* The channel's 3D position (position/velocity/orientation) are relative to
the listener. When the listener's position/velocity/orientation is changed
with BASS_Set3DPosition, the channel's position relative to the listener does
not change. */
#define BASS_3DMODE_OFF			2
/* Turn off 3D processing on the channel, the sound will be played
in the center. */

///////////////////////////////////////////////////////////////
// EAX presets, usage: BASS_SetEAXParameters(EAX_PRESET_xxx) //
///////////////////////////////////////////////////////////////
#define EAX_ENVIRONMENT_GENERIC          0
#define EAX_ENVIRONMENT_PADDEDCELL       1
#define EAX_ENVIRONMENT_ROOM             2
#define EAX_ENVIRONMENT_BATHROOM         3
#define EAX_ENVIRONMENT_LIVINGROOM       4
#define EAX_ENVIRONMENT_STONEROOM        5
#define EAX_ENVIRONMENT_AUDITORIUM       6
#define EAX_ENVIRONMENT_CONCERTHALL      7
#define EAX_ENVIRONMENT_CAVE             8
#define EAX_ENVIRONMENT_ARENA            9
#define EAX_ENVIRONMENT_HANGAR           10
#define EAX_ENVIRONMENT_CARPETEDHALLWAY  11
#define EAX_ENVIRONMENT_HALLWAY          12
#define EAX_ENVIRONMENT_STONECORRIDOR    13
#define EAX_ENVIRONMENT_ALLEY            14
#define EAX_ENVIRONMENT_FOREST           15
#define EAX_ENVIRONMENT_CITY             16
#define EAX_ENVIRONMENT_MOUNTAINS        17
#define EAX_ENVIRONMENT_QUARRY           18
#define EAX_ENVIRONMENT_PLAIN            19
#define EAX_ENVIRONMENT_PARKINGLOT       20
#define EAX_ENVIRONMENT_SEWERPIPE        21
#define EAX_ENVIRONMENT_UNDERWATER       22
#define EAX_ENVIRONMENT_DRUGGED          23
#define EAX_ENVIRONMENT_DIZZY            24
#define EAX_ENVIRONMENT_PSYCHOTIC        25
// total number of environments
#define EAX_ENVIRONMENT_COUNT            26

////////////////////////////////////////////////////////////////////////
// software 3D mixing algorithm modes (used with BASS_Set3DAlgorithm) //
////////////////////////////////////////////////////////////////////////
#define BASS_3DALG_DEFAULT	0
/* default algorithm (currently translates to BASS_3DALG_OFF) */
#define BASS_3DALG_OFF		1
/* Uses normal left and right panning. The vertical axis is ignored except for
scaling of volume due to distance. Doppler shift and volume scaling are still
applied, but the 3D filtering is not performed. This is the most CPU efficient
software implementation, but provides no virtual 3D audio effect. Head Related
Transfer Function processing will not be done. Since only normal stereo panning
is used, a channel using this algorithm may be accelerated by a 2D hardware
voice if no free 3D hardware voices are available. */
#define BASS_3DALG_FULL		2
/* This algorithm gives the highest quality 3D audio effect, but uses more CPU.
Requires Windows 98 2nd Edition or Windows 2000 that uses WDM drivers, if this
mode is not available then BASS_3DALG_OFF will be used instead. */
#define BASS_3DALG_LIGHT	3
/* This algorithm gives a good 3D audio effect, and uses less CPU than the FULL
mode. Requires Windows 98 2nd Edition or Windows 2000 that uses WDM drivers, if
this mode is not available then BASS_3DALG_OFF will be used instead. */

#define BASS_STREAMPROC_END		0x80000000	// end of user stream flag

//////////////////////////////////////
// BASS_StreamGetFilePosition modes //
//////////////////////////////////////
#define BASS_FILEPOS_CURRENT	0
#define BASS_FILEPOS_DECODE		BASS_FILEPOS_CURRENT
#define BASS_FILEPOS_DOWNLOAD	1
#define BASS_FILEPOS_END		2
#define BASS_FILEPOS_START		3

////////////////////////////
// STREAMFILEPROC actions //
////////////////////////////
#define BASS_FILE_CLOSE		0
#define BASS_FILE_READ		1
#define BASS_FILE_LEN		3
#define BASS_FILE_SEEK		4

///////////////////////////////////////////////////////////////////////////////////////////
// Sync types (with BASS_ChannelSetSync "param" and SYNCPROC "data" definitions) & flags //
///////////////////////////////////////////////////////////////////////////////////////////
#define BASS_SYNC_POS	    0
/* Sync when a channel reaches a position.
param: position in bytes
data : not used */
#define BASS_SYNC_END		2
/* Sync when a channel reaches the end.
param: not used
data : 1 = the sync is triggered by a backward jump in a MOD music, otherwise not used */
#define BASS_SYNC_META		4
/* Sync when metadata is received in a stream.
param: not used
data : pointer to the metadata */
#define BASS_SYNC_SLIDE		5
/* Sync when an attribute slide is completed.
param: not used
data : the type of slide completed (one of the BASS_SLIDE_xxx values) */
#define BASS_SYNC_STALL		6
/* Sync when playback has stalled.
param: not used
data : 0=stalled, 1=resumed */
#define BASS_SYNC_DOWNLOAD	7
/* Sync when downloading of an internet (or "buffered" user file) stream has ended.
param: not used
data : not used */
#define BASS_SYNC_FREE	    8
/* Sync when a channel is freed.
param: not used
data : not used */
#define BASS_SYNC_MUSICPOS	10
/* Sync when a MOD music reaches an order:row position.
param: LOWORD=order (0=first, -1=all) HIWORD=row (0=first, -1=all)
data : LOWORD=order HIWORD=row */
#define BASS_SYNC_MUSICINST	1
/* Sync when an instrument (sample for the non-instrument based formats)
is played in a MOD music (not including retrigs).
param: LOWORD=instrument (1=first) HIWORD=note (0=c0...119=b9, -1=all)
data : LOWORD=note HIWORD=volume (0-64) */
#define BASS_SYNC_MUSICFX	3
/* Sync when the "sync" effect (XM/MTM/MOD: E8x/Wxx, IT/S3M: S2x) is used.
param: 0:data=pos, 1:data="x" value
data : param=0: LOWORD=order HIWORD=row, param=1: "x" value */
#define BASS_SYNC_MESSAGE	0x20000000	// FLAG: post a Windows message (instead of callback)
/* When using a window message "callback", the message to post is given in the "proc"
parameter of BASS_ChannelSetSync, and is posted to the window specified in the BASS_Init
call. The message parameters are: WPARAM = data, LPARAM = user. */
#define BASS_SYNC_MIXTIME	0x40000000	// FLAG: sync at mixtime, else at playtime
#define BASS_SYNC_ONETIME	0x80000000	// FLAG: sync only once, else continuously

///////////////////////////////
// BASS_ChannelGetData flags //
///////////////////////////////
#define BASS_DATA_AVAILABLE	0			// query how much data is buffered
#define BASS_DATA_FLOAT		0x40000000	// flag: return floating-point sample data
#define BASS_DATA_FFT512	0x80000000	// 512 sample FFT
#define BASS_DATA_FFT1024	0x80000001	// 1024 FFT
#define BASS_DATA_FFT2048	0x80000002	// 2048 FFT
#define BASS_DATA_FFT4096	0x80000003	// 4096 FFT
#define BASS_DATA_FFT_INDIVIDUAL 0x10	// FFT flag: FFT for each channel, else all combined
#define BASS_DATA_FFT_NOWINDOW	0x20	// FFT flag: no Hanning window

/////////////////////////////////////////////////
// BASS_ChannelGetTags types : what's returned //
/////////////////////////////////////////////////
#define BASS_TAG_ID3		0	// ID3v1 tags : 128 byte block
#define BASS_TAG_ID3V2		1	// ID3v2 tags : variable length block
#define BASS_TAG_OGG		2	// OGG comments : array of null-terminated UTF-8 strings
#define BASS_TAG_HTTP		3	// HTTP headers : array of null-terminated ANSI strings
#define BASS_TAG_ICY		4	// ICY headers : array of null-terminated ANSI strings
#define BASS_TAG_META		5	// ICY metadata : ANSI string
#define BASS_TAG_VENDOR		9	// OGG encoder : UTF-8 string
#define BASS_TAG_RIFF_INFO	0x100 // RIFF/WAVE tags : array of null-terminated ANSI strings
#define BASS_TAG_MUSIC_NAME		0x10000	// MOD music name : ANSI string
#define BASS_TAG_MUSIC_MESSAGE	0x10001	// MOD message : ANSI string
#define BASS_TAG_MUSIC_INST		0x10100	// + instrument #, MOD instrument name : ANSI string
#define BASS_TAG_MUSIC_SAMPLE	0x10300	// + sample #, MOD sample name : ANSI string

////////////////////////////////////////
// BASS_MusicSet/GetAttribute options //
////////////////////////////////////////
#define BASS_MUSIC_ATTRIB_AMPLIFY	0
#define BASS_MUSIC_ATTRIB_PANSEP	1
#define BASS_MUSIC_ATTRIB_PSCALER	2
#define BASS_MUSIC_ATTRIB_BPM		3
#define BASS_MUSIC_ATTRIB_SPEED		4
#define BASS_MUSIC_ATTRIB_VOL_GLOBAL 5
#define BASS_MUSIC_ATTRIB_VOL_CHAN	0x100 // + channel #
#define BASS_MUSIC_ATTRIB_VOL_INST	0x200 // + instrument #

// BASS_ChannelGetLength/GetPosition/SetPosition modes
#define BASS_POS_BYTE			0		// byte position
#define BASS_POS_MUSIC_ORDER	1		// order.row position, MAKELONG(order,row)

//////////////////////////////////////////////////
// DX8 effect types, use with BASS_ChannelSetFX //
//////////////////////////////////////////////////
enum BASS_FX
{
	BASS_FX_CHORUS = 0,	    // GUID_DSFX_STANDARD_CHORUS
	BASS_FX_COMPRESSOR,		// GUID_DSFX_STANDARD_COMPRESSOR
	BASS_FX_DISTORTION,		// GUID_DSFX_STANDARD_DISTORTION
	BASS_FX_ECHO,			// GUID_DSFX_STANDARD_ECHO
	BASS_FX_FLANGER,		// GUID_DSFX_STANDARD_FLANGER
	BASS_FX_GARGLE,			// GUID_DSFX_STANDARD_GARGLE
	BASS_FX_I3DL2REVERB,	// GUID_DSFX_STANDARD_I3DL2REVERB
	BASS_FX_PARAMEQ,		// GUID_DSFX_STANDARD_PARAMEQ
	BASS_FX_REVERB			// GUID_DSFX_WAVES_REVERB
}

#define BASS_FX_PHASE_NEG_180        0
#define BASS_FX_PHASE_NEG_90         1
#define BASS_FX_PHASE_ZERO           2
#define BASS_FX_PHASE_90             3
#define BASS_FX_PHASE_180            4

////////////////////////////////////////
// BASS_ChannelIsActive return values //
////////////////////////////////////////
#define BASS_ACTIVE_STOPPED	0
#define BASS_ACTIVE_PLAYING	1
#define BASS_ACTIVE_STALLED	2
#define BASS_ACTIVE_PAUSED	3

////////////////////////////////////////
// BASS_ChannelIsSliding return flags //
////////////////////////////////////////
#define BASS_SLIDE_FREQ	1
#define BASS_SLIDE_VOL	2
#define BASS_SLIDE_PAN	4

///////////////////////////////
// BASS_RecordSetInput flags //
///////////////////////////////
#define BASS_INPUT_OFF		0x10000
#define BASS_INPUT_ON		0x20000
#define BASS_INPUT_LEVEL	0x40000

#define BASS_INPUT_TYPE_MASK		0xff000000
#define BASS_INPUT_TYPE_UNDEF		0x00000000
#define BASS_INPUT_TYPE_DIGITAL		0x01000000
#define BASS_INPUT_TYPE_LINE		0x02000000
#define BASS_INPUT_TYPE_MIC			0x03000000
#define BASS_INPUT_TYPE_SYNTH		0x04000000
#define BASS_INPUT_TYPE_CD			0x05000000
#define BASS_INPUT_TYPE_PHONE		0x06000000
#define BASS_INPUT_TYPE_SPEAKER		0x07000000
#define BASS_INPUT_TYPE_WAVE		0x08000000
#define BASS_INPUT_TYPE_AUX			0x09000000
#define BASS_INPUT_TYPE_ANALOG		0x0a000000

////////////////////////////////
// BASS_Set/GetConfig options //
////////////////////////////////
#define BASS_CONFIG_BUFFER			0
#define BASS_CONFIG_UPDATEPERIOD	1
#define BASS_CONFIG_GVOL_SAMPLE		4
#define BASS_CONFIG_GVOL_STREAM		5
#define BASS_CONFIG_GVOL_MUSIC		6
#define BASS_CONFIG_CURVE_VOL		7
#define BASS_CONFIG_CURVE_PAN		8
#define BASS_CONFIG_FLOATDSP		9
#define BASS_CONFIG_3DALGORITHM		10
#define BASS_CONFIG_NET_TIMEOUT		11
#define BASS_CONFIG_NET_BUFFER		12
#define BASS_CONFIG_PAUSE_NOPLAY	13
#define BASS_CONFIG_NET_PREBUF		15
#define BASS_CONFIG_NET_AGENT		16
#define BASS_CONFIG_NET_PROXY		17
#define BASS_CONFIG_NET_PASSIVE		18
#define BASS_CONFIG_MP3_CODEC		19


/////////////////////////////////
// BASS structures definitions //
/////////////////////////////////

struct BASS_INFO
{
	UNSIGNED INT flags;	    // device capabilities (DSCAPS_xxx flags)
	UNSIGNED INT hwsize;	// size of total device hardware memory
	UNSIGNED INT hwfree;	// size of free device hardware memory
	UNSIGNED INT freesam;	// number of free sample slots in the hardware
	UNSIGNED INT free3d;	// number of free 3D sample slots in the hardware
	UNSIGNED INT minrate;	// min sample rate supported by the hardware
	UNSIGNED INT maxrate;	// max sample rate supported by the hardware
	INT eax;		        // device supports EAX? (always FALSE if BASS_DEVICE_3D was not used)
	UNSIGNED INT minbuf;	// recommended minimum buffer length in ms (requires BASS_DEVICE_LATENCY)
	UNSIGNED INT dsver;	    // DirectSound version
	UNSIGNED INT latency;	// delay (in ms) before start of playback (requires BASS_DEVICE_LATENCY)
	UNSIGNED INT initflags; // "flags" parameter of BASS_Init call
	UNSIGNED INT speakers;  // number of speakers available
}

struct BASS_DEVICEINFO
{
	Byte *name;	// description
	Byte *driver;	// driver
	UNSIGNED INT flags;
}

struct BASS_RECORDINFO
{
	UNSIGNED INT flags;	    // device capabilities (DSCCAPS_xxx flags)
	UNSIGNED INT formats;	// supported standard formats (WAVE_FORMAT_xxx flags)
	UNSIGNED INT inputs;	// number of inputs
	INT singlein;	        // TRUE = only 1 input can be set at a time
}

// Sample info structure & flags
struct BASS_SAMPLE
{
	UNSIGNED INT freq;		// default playback rate
	UNSIGNED INT volume;	// default volume (0-100)
	int pan;		        // default pan (-100=left, 0=middle, 100=right)
	UNSIGNED INT flags;	    // BASS_SAMPLE_xxx flags
	UNSIGNED INT length;	// length (in bytes)
	UNSIGNED INT max;		// maximum simultaneous playbacks
	UNSIGNED INT origres;	// original resolution bits
	UNSIGNED INT chans;	    // number of channels
	UNSIGNED INT mingap;	// minimum gap (ms) between creating channels
/* The following are the sample's default 3D attributes (if the sample
is 3D, BASS_SAMPLE_3D is in flags) see BASS_ChannelSet3DAttributes */
	UNSIGNED INT mode3d;	// BASS_3DMODE_xxx mode
	float mindist;	        // minimum distance
	float maxdist;	        // maximum distance
	UNSIGNED INT iangle;	// angle of inside projection cone
	UNSIGNED INT oangle;	// angle of outside projection cone
	UNSIGNED INT outvol;	// delta-volume outside the projection cone
/* The following are the defaults used if the sample uses the DirectX 7
voice allocation/management features. */
	UNSIGNED INT vam;		// voice allocation/management flags (BASS_VAM_xxx)
	UNSIGNED INT priority;	// priority (0=lowest, 0xffffffff=highest)
}

struct BASS_CHANNELINFO
{
	UNSIGNED INT freq;		// default playback rate
	UNSIGNED INT chans;	    // channels
	UNSIGNED INT flags;	    // BASS_SAMPLE/STREAM/MUSIC/SPEAKER flags
	UNSIGNED INT ctype;	    // type of channel
	UNSIGNED INT origres;	// original resolution
	HPLUGIN plugin;	        // plugin
	HSAMPLE sample;
    Byte *filename;
}

struct BASS_PLUGINFORM
{
	UNSIGNED INT ctype;		// channel type
	Byte *name;	    // format description
	Byte *exts;	    // file extension filter (*.ext1;*.ext2;etc...)
}

struct BASS_PLUGININFO
{
	UNSIGNED INT version;	// version (same form as BASS_GetVersion)
	UNSIGNED INT formatc;   // number of formats
	BASS_PLUGINFORM *formats;	// the array of formats
} 

//////////////////////////////////////////////////////////
// 3D vector (for 3D positions/velocities/orientations) //
//////////////////////////////////////////////////////////
struct BASS_3DVECTOR 
{
	float x;	// +=right, -=left
	float y;	// +=up, -=down
	float z;	// +=front, -=behind
}

//////////////
//  Effects //
//////////////
struct BASS_FXCHORUS
{// DSFXChorus
    float       fWetDryMix;
    float       fDepth;
    float       fFeedback;
    float       fFrequency;
    UNSIGNED INT       lWaveform;	// 0=triangle, 1=sine
    float       fDelay;
    UNSIGNED INT       lPhase;		// BASS_FX_PHASE_xxx
}
struct BASS_FXCOMPRESSOR 
{// DSFXCompressor
    float   fGain;
    float   fAttack;
    float   fRelease;
    float   fThreshold;
    float   fRatio;
    float   fPredelay;
}

struct BASS_FXDISTORTION 
{// DSFXDistortion
    float   fGain;
    float   fEdge;
    float   fPostEQCenterFrequency;
    float   fPostEQBandwidth;
    float   fPreLowpassCutoff;
}	

struct BASS_FXECHO 
{// DSFXEcho
    float   fWetDryMix;
    float   fFeedback;
    float   fLeftDelay;
    float   fRightDelay;
    INT    lPanDelay;
}		

struct BASS_FXFLANGER 
{// DSFXFlanger
    float       fWetDryMix;
    float       fDepth;
    float       fFeedback;
    float       fFrequency;
    UNSIGNED INT       lWaveform;	// 0=triangle, 1=sine
    float       fDelay;
    UNSIGNED INT       lPhase;		// BASS_FX_PHASE_xxx
}		

struct BASS_FXGARGLE 
{// DSFXGargle
    UNSIGNED INT       dwRateHz;               // Rate of modulation in hz
    UNSIGNED INT       dwWaveShape;            // 0=triangle, 1=square
} 		

struct BASS_FXI3DL2REVERB 
{// DSFXI3DL2Reverb
    int     lRoom;                  // [-10000, 0]      default: -1000 mB
    int     lRoomHF;                // [-10000, 0]      default: 0 mB
    float   flRoomRolloffFactor;    // [0.0, 10.0]      default: 0.0
    float   flDecayTime;            // [0.1, 20.0]      default: 1.49s
    float   flDecayHFRatio;         // [0.1, 2.0]       default: 0.83
    int     lReflections;           // [-10000, 1000]   default: -2602 mB
    float   flReflectionsDelay;     // [0.0, 0.3]       default: 0.007 s
    int     lReverb;                // [-10000, 2000]   default: 200 mB
    float   flReverbDelay;          // [0.0, 0.1]       default: 0.011 s
    float   flDiffusion;            // [0.0, 100.0]     default: 100.0 %
    float   flDensity;              // [0.0, 100.0]     default: 100.0 %
    float   flHFReference;          // [20.0, 20000.0]  default: 5000.0 Hz
}	

struct BASS_FXPARAMEQ 
{// DSFXParamEq
    float   fCenter;
    float   fBandwidth;
    float   fGain;
}		

struct BASS_FXREVERB 
{// DSFXWavesReverb
    float   fInGain;                // [-96.0,0.0]            default: 0.0 dB
    float   fReverbMix;             // [-96.0,0.0]            default: 0.0 db
    float   fReverbTime;            // [0.001,3000.0]         default: 1000.0 ms
    float   fHighFreqRTRatio;       // [0.001,0.999]          default: 0.001
} 

///////////////////////////////////////////////////////////////////////////////////
//                             BASS FUNCTIONS                                    //
///////////////////////////////////////////////////////////////////////////////////
Declare Import, BASS_SetConfig(UNSIGNED INT option, UNSIGNED INT value),INT;
Declare Import, BASS_GetConfig(UNSIGNED INT option),UNSIGNED INT;
Declare Import, BASS_GetVersion(),UNSIGNED INT;
Declare Import, BASS_GetDeviceInfo(UNSIGNED INT device, BASS_DEVICEINFO *info);
Declare Import, BASS_ErrorGetCode(),INT;
Declare Import, BASS_Init(INT device, UNSIGNED INT freq, UNSIGNED INT flags, INT win, INT *clsid),INT;
Declare Import, BASS_SetDevice(UNSIGNED INT device),INT;
Declare Import, BASS_GetDevice(),UNSIGNED INT;
Declare Import, BASS_Free(),INT;
Declare Import, BASS_GetDSoundObject(UNSIGNED INT object),POINTER;
Declare Import, BASS_GetInfo(BASS_INFO *info ByRef),INT;
Declare Import, BASS_Update(UNSIGNED INT length),INT;
Declare Import, BASS_GetCPU(),FLOAT;
Declare Import, BASS_Start(),INT;
Declare Import, BASS_Stop(),INT;
Declare Import, BASS_Pause(),INT;
Declare Import, BASS_SetVolume(FLOAT volume),INT;
//Use BASSGetVolume() instead with Aurora
Declare Import, BASS_GetVolume(),FLOAT;

Declare Import, BASS_PluginLoad(Byte *filename, UNSIGNED INT flags),HPLUGIN;
Declare Import, BASS_PluginFree(HPLUGIN handle),INT;
Declare Import, BASS_PluginGetInfo(HPLUGIN handle),POINTER;

Declare Import, BASS_Set3DFactors(FLOAT distf, FLOAT rollf, FLOAT doppf),INT;
Declare Import, BASS_Get3DFactors(FLOAT *distf ByRef,FLOAT *rollf ByRef, FLOAT *doppf ByRef),INT;
Declare Import, BASS_Set3DPosition(BASS_3DVECTOR *pos ByRef, BASS_3DVECTOR *vel ByRef, BASS_3DVECTOR *front ByRef, BASS_3DVECTOR *top ByRef),INT;
Declare Import, BASS_Get3DPosition(BASS_3DVECTOR *pos ByRef, BASS_3DVECTOR *vel ByRef, BASS_3DVECTOR *front ByRef, BASS_3DVECTOR *top ByRef),INT;
Declare Import, BASS_Apply3D(),INT;

Declare Import, BASS_SetEAXParameters(INT env, FLOAT vol, FLOAT decay , FLOAT damp),INT;
Declare Import, BASS_GetEAXParameters(UNSIGNED INT *env ByRef, FLOAT *vol ByRef, FLOAT *decay ByRef, FLOAT *damp ByRef),INT;

Declare Import, BASS_MusicLoad(INT mem, void *f, UNSIGNED INT64 offset, UNSIGNED INT length, UNSIGNED INT flags, UNSIGNED INT freq),HMUSIC;
Declare Import, BASS_MusicFree(HMUSIC handle),INT;

Declare Import, BASS_SampleLoad(INT mem , void *f, UNSIGNED INT64 offset, UNSIGNED INT length, UNSIGNED INT max, UNSIGNED INT flags),HSAMPLE;
Declare Import, BASS_SampleCreate(UNSIGNED INT length, UNSIGNED INT freq, UNSIGNED INT chans, UNSIGNED INT max, UNSIGNED INT flags),POINTER;
Declare Import, BASS_SampleFree(HSAMPLE handle),INT;
Declare Import, BASS_SampleSetData(HSAMPLE handle, void *buffer);
Declare Import, BASS_SampleGetData(HSAMPLE handle, void *buffer);
Declare Import, BASS_SampleGetInfo(HSAMPLE handle, BASS_SAMPLE *info ByRef),INT;
Declare Import, BASS_SampleSetInfo(HSAMPLE handle, BASS_SAMPLE *info ByRef),INT;
Declare Import, BASS_SampleGetChannel(HSAMPLE handle, INT onlynew),HCHANNEL;
Declare Import, BASS_SampleStop(HSAMPLE handle),INT;

Declare Import, BASS_StreamCreate(UNSIGNED INT freq, UNSIGNED INT chans, UNSIGNED INT flags, STREAMPROC *proc, UNSIGNED INT user),HSTREAM;
Declare Import, BASS_StreamCreateFile(INT mem, void *f, UNSIGNED INT64 offset, UNSIGNED INT64 length, UNSIGNED INT flags),HSTREAM;
Declare Import, BASS_StreamCreateURL(Byte *url, UNSIGNED INT offset, UNSIGNED INT flags, DOWNLOADPROC *proc, UNSIGNED INT user),HSTREAM;
Declare Import, BASS_StreamCreateFileUser(INT buffered, UNSIGNED INT flags, STREAMFILEPROC *proc, UNSIGNED INT user),HSTREAM;
Declare Import, BASS_StreamFree(HSTREAM handle),INT;
Declare Import, BASS_StreamGetFilePosition(HSTREAM handle, UNSIGNED INT mode),UNSIGNED INT64;

Declare Import, BASS_RecordGetDeviceDescription(UNSIGNED INT device),POINTER;//*Byte
Declare Import, BASS_RecordInit(INT device),INT;
Declare Import, BASS_RecordSetDevice(UNSIGNED INT device),INT;
Declare Import, BASS_RecordGetDevice(),UNSIGNED INT;
Declare Import, BASS_RecordFree(),INT;
Declare Import, BASS_RecordGetInfo(BASS_RECORDINFO *info ByRef),INT;
Declare Import, BASS_RecordGetInputName(INT inputn),POINTER;//*Byte
Declare Import, BASS_RecordSetInput(INT input, UNSIGNED INT flags, FLOAT volume),INT;
Declare Import, BASS_RecordGetInput(INT input, FLOAT volume),UNSIGNED INT;
Declare Import, BASS_RecordStart(UNSIGNED INT freq, UNSIGNED INT chans, UNSIGNED INT flags, RECORDPROC *proc, UNSIGNED INT user),HRECORD;

Declare Import, BASS_ChannelBytes2Seconds(UNSIGNED INT handle, UNSIGNED INT64 pos),DOUBLE;
Declare Import, BASS_ChannelSeconds2Bytes(UNSIGNED INT handle, DOUBLE pos),UNSIGNED INT64;
Declare Import, BASS_ChannelGetDevice(UNSIGNED INT handle),UNSIGNED INT;
Declare Import, BASS_ChannelSetDevice(UNSIGNED INT handle, UNSIGNED INT device),INT;
Declare Import, BASS_ChannelIsActive(UNSIGNED INT handle),UNSIGNED INT;
Declare Import, BASS_ChannelGetInfo(UNSIGNED INT handle, BASS_CHANNELINFO *info ByRef),INT;
Declare Import, BASS_ChannelGetTags(UNSIGNED INT handle, UNSIGNED INT tags),POINTER;//*Byte
Declare Import, BASS_ChannelFlags(UNSIGNED INT handle, UNSIGNED INT flags, UNSIGNED INT mask),UNSIGNED INT;
Declare Import, BASS_ChannelUpdate(UNSIGNED INT handle, UNSIGNED INT length),INT;
Declare Import, BASS_ChannelPlay(UNSIGNED INT handle, INT restart),INT;
Declare Import, BASS_ChannelStop(UNSIGNED INT handle),INT;
Declare Import, BASS_ChannelPause(UNSIGNED INT handle),INT;
Declare Import, BASS_ChannelSetAttribute(UNSIGNED INT handle, UNSIGNED INT attrib, FLOAT value),INT;
Declare Import, BASS_ChannelGetAttribute(UNSIGNED INT handle, UNSIGNED INT attrib, FLOAT *value),INT;
Declare Import, BASS_ChannelSlideAttribute(UNSIGNED INT handle, INT freq, INT volume, INT pan, UNSIGNED INT time),INT;
Declare Import, BASS_ChannelIsSliding(UNSIGNED INT handle ,UNSIGNED INT attrib),UNSIGNED INT;
Declare Import, BASS_ChannelSet3DAttributes(UNSIGNED INT handle, INT mode, FLOAT min, FLOAT max, INT iangle, INT oangle, INT outvol),INT;
Declare Import, BASS_ChannelGet3DAttributes(UNSIGNED INT handle, UNSIGNED INT *mode ByRef, FLOAT *min ByRef, FLOAT *max ByRef, UNSIGNED INT *iangle ByRef, UNSIGNED INT *oangle ByRef, UNSIGNED INT *outvol ByRef),INT;
Declare Import, BASS_ChannelSet3DPosition(UNSIGNED INT handle, BASS_3DVECTOR *pos ByRef, BASS_3DVECTOR *orient ByRef, BASS_3DVECTOR *vel ByRef),INT;
Declare Import, BASS_ChannelGet3DPosition(UNSIGNED INT handle, BASS_3DVECTOR *pos ByRef, BASS_3DVECTOR *orient ByRef, BASS_3DVECTOR *vel ByRef),INT;
Declare Import, BASS_ChannelGetLength(UNSIGNED INT handle, UNSIGNED INT mode),UNSIGNED INT64;
Declare Import, BASS_ChannelSetPosition(UNSIGNED INT handle, UNSIGNED INT64 pos, UNSIGNED INT mode),INT;
Declare Import, BASS_ChannelGetPosition(UNSIGNED INT handle, UNSIGNED INT mode),UNSIGNED INT64;
Declare Import, BASS_ChannelGetLevel(UNSIGNED INT handle),UNSIGNED INT;
Declare Import, BASS_ChannelGetData(UNSIGNED INT handle, VOID *buffer ByRef, UNSIGNED INT length),UNSIGNED INT;
Declare Import, BASS_ChannelSetSync(UNSIGNED INT handle, UNSIGNED INT atype, UNSIGNED INT64 param, UNSIGNED INT64 paramhigh, SYNCPROC *proc, UNSIGNED INT user),HSYNC;
Declare Import, BASS_ChannelRemoveSync(UNSIGNED INT handle, HSYNC sync),INT;
Declare Import, BASS_ChannelSetDSP(UNSIGNED INT handle, DSPPROC *proc, UNSIGNED INT user, INT priority),HDSP;
Declare Import, BASS_ChannelRemoveDSP(UNSIGNED INT handle, HDSP dsp),INT;
Declare Import, BASS_ChannelSetLink(UNSIGNED INT handle, UNSIGNED INT chan),INT;
Declare Import, BASS_ChannelRemoveLink(UNSIGNED INT handle, UNSIGNED INT chan),INT;
Declare Import, BASS_ChannelSetEAXMix(UNSIGNED INT handle, FLOAT mix),INT;
Declare Import, BASS_ChannelGetEAXMix(UNSIGNED INT handle, FLOAT *mix ByRef),INT;
Declare Import, BASS_ChannelSetFX(UNSIGNED INT handle, UNSIGNED INT atype, UNSIGNED INT priority),HFX;
Declare Import, BASS_ChannelRemoveFX(UNSIGNED INT handle, HFX fx),INT;
Declare Import, BASS_FXSetParameters(HFX handle, VOID *par ByRef),INT;
Declare Import, BASS_FXGetParameters(HFX handle, VOID *par ByRef),INT;

//Use this instead with Aurora
sub BASSGetVolume(),float
{
	float vol;
	BASS_GetVolume();
	#emit fstp dword[ebp-4]
	return vol;
}

/*
import VOID CopyMemory Alias RtlMoveMemory(POINTER Destination ByRef, POINTER Source ByRef, INT length);

GLOBAL SUB BASS_SPEAKER_N(INT n),INT
{
    return n * (2 ^ 24);
}

GLOBAL SUB BASS_SetEAXPreset(INT Preset),INT
{
//This function is a workaround, because Aurora doesn't support multiple comma seperated
//paramaters for each Global Const, simply pass the EAX_ENVIRONMENT_xxx value to this function
//instead of BASS_SetEAXParameters as you would do in C++
INT setpreset = null;
Select Preset
{
    Case EAX_ENVIRONMENT_GENERIC:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_GENERIC, 0.5, 1.493, 0.5);
    Case EAX_ENVIRONMENT_PADDEDCELL:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_PADDEDCELL, 0.25, 0.1, 0);
    Case EAX_ENVIRONMENT_ROOM:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_ROOM, 0.417, 0.4, 0.666);
    Case EAX_ENVIRONMENT_BATHROOM:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_BATHROOM, 0.653, 1.499, 0.166);
    Case EAX_ENVIRONMENT_LIVINGROOM:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_LIVINGROOM, 0.208, 0.478, 0);
    Case EAX_ENVIRONMENT_STONEROOM:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_STONEROOM, 0.5, 2.309, 0.888);
    Case EAX_ENVIRONMENT_AUDITORIUM:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_AUDITORIUM, 0.403, 4.279, 0.5);
    Case EAX_ENVIRONMENT_CONCERTHALL:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_CONCERTHALL, 0.5, 3.961, 0.5);
    Case EAX_ENVIRONMENT_CAVE:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_CAVE, 0.5, 2.886, 1.304);
    Case EAX_ENVIRONMENT_ARENA:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_ARENA, 0.361, 7.284, 0.332);
    Case EAX_ENVIRONMENT_HANGAR:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_HANGAR, 0.5, 10, 0.3);
    Case EAX_ENVIRONMENT_CARPETEDHALLWAY:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_CARPETEDHALLWAY, 0.153, 0.259, 2);
    Case EAX_ENVIRONMENT_HALLWAY:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_HALLWAY, 0.361, 1.493, 0);
    Case EAX_ENVIRONMENT_STONECORRIDOR:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_STONECORRIDOR, 0.444, 2.697, 0.638);
    Case EAX_ENVIRONMENT_ALLEY:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_ALLEY, 0.25, 1.752, 0.776);
    Case EAX_ENVIRONMENT_FOREST:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_FOREST, 0.111, 3.145, 0.472);
    Case EAX_ENVIRONMENT_CITY:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_CITY, 0.111, 2.767, 0.224);
    Case EAX_ENVIRONMENT_MOUNTAINS:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_MOUNTAINS, 0.194, 7.841, 0.472);
    Case EAX_ENVIRONMENT_QUARRY:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_QUARRY, 1, 1.499, 0.5);
    Case EAX_ENVIRONMENT_PLAIN:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_PLAIN, 0.097, 2.767, 0.224);
    Case EAX_ENVIRONMENT_PARKINGLOT:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_PARKINGLOT, 0.208, 1.652, 1.5);
    Case EAX_ENVIRONMENT_SEWERPIPE:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_SEWERPIPE, 0.652, 2.886, 0.25);
    Case EAX_ENVIRONMENT_UNDERWATER:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_UNDERWATER, 1, 1.499, 0);
    Case EAX_ENVIRONMENT_DRUGGED:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_DRUGGED, 0.875, 8.392, 1.388);
    Case EAX_ENVIRONMENT_DIZZY:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_DIZZY, 0.139, 17.234, 0.666);
    Case EAX_ENVIRONMENT_PSYCHOTIC:
        setpreset = BASS_SetEAXParameters(EAX_ENVIRONMENT_PSYCHOTIC, 0.486, 7.563, 0.806);
}
return setpreset;
}
*/

/*
GLOBAL SUB HiWord(INT lparam),INT
{
//This is the HIWORD of the lParam:
return lparam / 0x10000 And 0xFFFF;
}
GLOBAL SUB LoWord(INT lparam),INT
{
//This is the LOWORD of the lParam:
return lparam And 0xFFFF;
}
GLOBAL SUB MakeLong(INT LoWord, INT HiWord),INT
{
//Replacement for the c++ Function MAKELONG
return (LoWord And 0xFFFF) Or (HiWord * 0x10000);
}
*/
/////////////////////////////
// BASS CALLBACK FUNCTIONS //
/////////////////////////////

//GLOBAL SUB STREAMFILEPROC(INT action, INT param1, INT param2, INT user),INT
//{
/* User file stream callback function.
action : The action to perform, one of BASS_FILE_xxx values.
param1 : Depends on "action"
param2 : Depends on "action"
user   : The 'user' parameter value given when calling BASS_StreamCreate
RETURN : Depends on "action" */
//}

//GLOBAL SUB DOWNLOADPROC(INT buffer, INT length, INT user)
//{
/* Internet stream download callback function.
buffer : Buffer containing the downloaded data... NULL=end of download
length : Number of bytes in the buffer
user   : The 'user' parameter value given when calling BASS_StreamCreateURL */
//}

//GLOBAL SUB STREAMPROC(INT handle, INT buffer, INT length, INT user),INT
//{
/* User stream callback function. NOTE: A stream function should obviously be as quick
as possible, other streams (and MOD musics) can't be mixed until it's finished.
handle : The stream that needs writing
buffer : Buffer to write the samples in
length : Number of bytes to write
user   : The 'user' parameter value given when calling BASS_StreamCreate
RETURN : Number of bytes written. Set the BASS_STREAMPROC_END flag to end
         the stream. */
//}

//GLOBAL SUB SYNCPROC(INT handle, INT channel, INT data, INT user)
//{
/* Sync callback function. NOTE: a sync callback function should be very
quick as other syncs can't be processed until it has finished. If the sync
is a "mixtime" sync, then other streams and MOD musics can't be mixed until
it's finished either.
handle : The sync that has occured
channel: Channel that the sync occured in
data   : Additional data associated with the sync's occurance
user   : The 'user' parameter given when calling BASS_ChannelSetSync */
//}

//GLOBAL SUB DSPPROC(INT handle, INT channel, INT buffer, INT length, INT user)
//{
/* DSP callback function. NOTE: A DSP function should obviously be as quick as
possible... other DSP functions, streams and MOD musics can not be processed
until it's finished.
handle : The DSP handle
channel: Channel that the DSP is being applied to
buffer : Buffer to apply the DSP to
length : Number of bytes in the buffer
user   : The 'user' parameter given when calling BASS_ChannelSetDSP */
//}

//GLOBAL SUB RECORDPROC(INT handle, INT buffer, INT length, INT user),INT
//{
/* Recording callback function.
handle : The recording handle
buffer : Buffer containing the recorded sample data
length : Number of bytes
user   : The 'user' parameter value given when calling BASS_RecordStart
RETURN : TRUE = continue recording, FALSE = stop */
//}

#endif